@@ -21,7 +21,6 @@ import time
 from pathlib import Path
 from typing import Type
 
-import yaml
 import requests
 
 from manifesttool.dev_tool import defaults
@@ -31,7 +30,7 @@ from manifesttool.dev_tool.actions.create \
     import register_parser as register_create_parser
 from manifesttool.dev_tool.actions.create import create_dev_manifest
 from manifesttool.dev_tool.pelion import pelion
-from manifesttool.mtool.actions import non_negative_int_arg_factory
+from manifesttool.common.common_helpers import get_non_negative_int_argument
 from manifesttool.mtool.asn1 import ManifestAsnCodecBase
 
 logger = logging.getLogger('manifest-dev-tool-update')
@@ -68,7 +67,7 @@ def register_parser(parser: argparse.ArgumentParser, schema_version: str):
     )
     pdm_group.add_argument(
         '-t', '--timeout',
-        type=non_negative_int_arg_factory,
+        type=get_non_negative_int_argument,
         help='Wait timeout in seconds. '
              '[Default: 0 - wait-forever]',
         default=0
@@ -80,7 +79,7 @@ def register_parser(parser: argparse.ArgumentParser, schema_version: str):
              'Only relevant if --wait-for-completion was provided.'
     )
 
-def _manage_campaign(api: pelion.UpdateServiceApi,
+def _manage_campaign(api: pelion.PelionServiceApi,
                      campaign_id: pelion.ID,
                      end_time: int,
                      do_wait: bool):
@@ -88,7 +87,7 @@ def _manage_campaign(api: pelion.UpdateServiceApi,
     old_state = ''
     try:
         api.campaign_start(campaign_id)
-    except requests.HTTPError as ex:
+    except requests.HTTPError:
         logger.error('Failed to start campaign %s', campaign_id)
         raise
     try:
@@ -123,7 +122,7 @@ def _manage_campaign(api: pelion.UpdateServiceApi,
             time.sleep(3)
         logger.error('Campaign timed out')
         raise AssertionError('Campaign timed out')
-    except requests.HTTPError as ex:
+    except requests.HTTPError:
         logger.error('Failed to retrieve campaign state')
         raise
 
@@ -152,7 +151,7 @@ def _print_summary(summary: dict, summary_reasons: dict):
                 logger.warning(" %s", reasons.get('description'))
 
 
-def _finalize(api: pelion.UpdateServiceApi,
+def _finalize(api: pelion.PelionServiceApi,
               do_cleanup: bool,
               campaign_id: pelion.ID,
               manifest_id: pelion.ID,
@@ -216,37 +215,57 @@ def update(
         fw_version: str,
         sign_image: bool,
         component: str,
-        short_url: bool
+        short_url: bool,
+        encrypt_payload: bool,
+        combined_package: bool
 ):
-    config = load_service_config(service_config)
-
-    api = pelion.UpdateServiceApi(
-        host=config['host'], access_key=config['access_key'])
+    api = pelion.PelionServiceApi(service_config)
     manifest_path = None
     fw_image_id = None
     manifest_id = None
     campaign_id = None
+    encrypted_digest = None
+    encrypted_size = None
     try:
         timestamp = time.strftime('%Y_%m_%d-%H_%M_%S')
         logger.info('Uploading FW image %s', payload_path.as_posix())
 
-        fw_image_url, short_image_url, fw_image_id = api.fw_upload(
-            fw_name='{timestamp}-{filename}'.format(
-                filename=payload_path.name,
-                timestamp=timestamp),
-            image=payload_path
+        fw_meta = api.fw_upload(
+            fw_name='{}-{}'.format(timestamp, payload_path.name),
+            image=payload_path,
+            encrypt=encrypt_payload
         )
 
+        fw_image_id = fw_meta['id']
+        payload_url = fw_meta['short_datafile' if short_url else 'datafile']
+
+        if encrypt_payload:
+            if fw_meta.get('datafile_encryption', False) and \
+               fw_meta.get('encrypted_datafile_checksum', False) and \
+               fw_meta.get('encrypted_datafile_size', False):
+                encrypted_digest = \
+                    fw_meta['encrypted_datafile_checksum']
+                encrypted_size = \
+                    fw_meta['encrypted_datafile_size']
+            else:
+                raise AssertionError(
+                    'Request to encrypt payload failed! '
+                    'Device Management doesn\'t support this feature.'
+                )
+
         manifest_data = create_dev_manifest(
             dev_cfg=dev_cfg,
             manifest_version=manifest_version,
             vendor_data_path=vendor_data,
             payload_path=payload_path,
-            payload_url=short_image_url if short_url else fw_image_url,
+            payload_url=payload_url,
+            encrypted_digest=encrypted_digest,
+            encrypted_size=encrypted_size,
             priority=priority,
             fw_version=fw_version,
             sign_image=sign_image,
-            component=component
+            component=component,
+            combined_package=combined_package
         )
 
         manifest_name = 'manifest-{timestamp}-{filename}'.format(
@@ -280,6 +299,12 @@ def update(
         if do_start:
             _manage_campaign(api, campaign_id, end_time, do_wait)
 
+    except requests.HTTPError as ex:
+        # log additional service info
+        srv_message = ex.response.json().get('message', None)
+        if srv_message:
+            logger.error(srv_message)
+        raise
     except KeyboardInterrupt:
         logger.error('Aborted by user...')
     finally:
@@ -292,21 +317,6 @@ def update(
                       manifest_path)
 
 
-def load_service_config(service_config):
-    if service_config.is_file():
-        with service_config.open('rt') as fh:
-            config = yaml.safe_load(fh)
-            if 'host' in config and 'access_key' in config:
-                return config
-            if 'host' in config and 'api_key' in config:
-                # replace api_key with access_key for backward compatibility
-                config['access_key'] = config.pop('api_key')
-                return config
-    raise AssertionError('Pelion service configurations (URL and access key) '
-                         'are not provided for assisted campaign '
-                         'management')
-
-
 def entry_point(
         args,
         manifest_version: Type[ManifestAsnCodecBase]
@@ -314,6 +324,9 @@ def entry_point(
     dev_cfg, fw_version = \
         load_cfg_and_get_fw_ver(args, manifest_version)
 
+    encrypt_payload = \
+        hasattr(args, 'encrypt_payload') and args.encrypt_payload
+
     update(
         payload_path=args.payload_path,
         dev_cfg=dev_cfg,
@@ -329,5 +342,7 @@ def entry_point(
         fw_version=fw_version,
         sign_image=getattr(args, 'sign_image', False),
         component=getattr(args, 'component_name', None),
-        short_url=hasattr(args, 'use_short_url') and args.use_short_url
+        short_url=hasattr(args, 'use_short_url') and args.use_short_url,
+        encrypt_payload=encrypt_payload,
+        combined_package=getattr(args, 'combined_image', False)
     )
