@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright 2019-2020 Pelion
+# Copyright 2019-2021 Pelion
 #
 # SPDX-License-Identifier: Apache-2.0
 #
@@ -19,8 +19,7 @@ import argparse
 from pathlib import Path
 
 from manifesttool.mtool import ecdsa_helper
-from manifesttool.mtool.actions import existing_file_path_arg_factory
-
+from manifesttool.common.common_helpers import get_argument_path
 
 class PublicKeyAction:
     @staticmethod
@@ -31,7 +30,7 @@ class PublicKeyAction:
         required.add_argument(
             'private_key',
             help='Path to a private key PEM file.',
-            type=existing_file_path_arg_factory,
+            type=get_argument_path,
         )
 
         required.add_argument(
